{ pkgs, config, lib, modulesPath, ... }:
{
  environment.systemPackages = with pkgs; [
    # Brightness control for display.
    brightnessctl
  ];

  imports =
    [ (modulesPath + "/installer/scan/not-detected.nix")
    ];

  systemd.tmpfiles.settings = {
    "10-secrets" = {
      "/secrets".v = {
        user = "nero";
        mode = "0760";
      };
    };
  };

  services.blueman.enable = true;

  boot.kernelPackages = pkgs.linuxPackages_latest;
  boot.kernelModules = [ "btusb" "kvm-amd" ];

  boot.initrd.availableKernelModules = [ "nvme" "xhci_pci" "thunderbolt" "usb_storage" "sd_mod" ];
  boot.initrd.kernelModules = [ "amdgpu" ];
  boot.extraModulePackages = [ ];

  networking.useDHCP = lib.mkDefault true;

  hardware.graphics = {
    enable = true;
    enable32Bit = true;

    extraPackages = with pkgs; [
      amdvlk
    ];
    extraPackages32 = with pkgs; [
      driversi686Linux.amdvlk
    ];
  };

  nixpkgs.hostPlatform = lib.mkDefault "x86_64-linux";
  hardware.enableRedistributableFirmware = true;
  hardware.cpu.amd.updateMicrocode = lib.mkDefault config.hardware.enableRedistributableFirmware;
}
